==> convertmask-0.3.3.tar.gz: convertmask-0.3.3/convertmask/utils/cpFile.py <==
'''
@lanhuage: python
@Descripttion: 
@version: beta
@Author: xiaoshuyui
@Date: 2020-07-13 16:43:58
LastEditors: xiaoshuyui
LastEditTime: 2020-08-20 08:46:32
'''
import os
from labelme import utils
import shutil

pa = utils.__file__
father_path=os.path.abspath(os.path.dirname(pa)+os.path.sep+".")

BASE_DIR = os.path.abspath(os.curdir)
drawFile = BASE_DIR+os.sep+ 'draw.py'
# print(drawFile)

def cp():
    # print(drawFile)
    if os.path.exists(father_path+os.sep+'draw.py') :
        pass
    else:
        shutil.copy(drawFile,father_path+os.sep)
        f = open(pa,'a')
        lis = [
            'from .draw import label_colormap',
            'from .draw import _validate_colormap',
            'from .draw import label2rgb',
            'from .draw import draw_label',
            'from .draw import draw_instances' 
        ]

        for i in lis:
            f.write(i+'\n')
        
        f.close()


def fileExist():
    # print(drawFile)
    if os.path.exists(father_path+os.sep+'draw.py') :
        # pass
        return True
    else:
        return False
        # shutil.copy(drawFile,father_path+os.sep)
        # f = open(pa,'a')
        # lis = [
        #     'from .draw import label_colormap',
        #     'from .draw import _validate_colormap',
        #     'from .draw import label2rgb',
        #     'from .draw import draw_label',
        #     'from .draw import draw_instances' 
        # ]

        # for i in lis:
        #     f.write(i+'\n')
        
        # f.close()

==> convertmask-0.5.2.tar.gz: convertmask-0.5.2/convertmask/utils/cpFile.py <==
'''
@lanhuage: python
@Descripttion: 
@version: beta
@Author: xiaoshuyui
@Date: 2020-07-13 16:43:58
LastEditors: xiaoshuyui
LastEditTime: 2020-10-10 15:48:38
'''
import os
from labelme import utils
import shutil

pa = utils.__file__
father_path = os.path.abspath(os.path.dirname(pa) + os.path.sep + ".")

BASE_DIR = os.path.abspath(os.curdir)
drawFile = BASE_DIR + os.sep + 'draw.py'
# print(drawFile)


def cp():
    # print(drawFile)
    if os.path.exists(father_path + os.sep + 'draw.py'):
        pass
    else:
        shutil.copy(drawFile, father_path + os.sep)
        f = open(pa, 'a')
        lis = [
            'from .draw import label_colormap',
            'from .draw import _validate_colormap',
            'from .draw import label2rgb', 'from .draw import draw_label',
            'from .draw import draw_instances'
        ]

        for i in lis:
            f.write(i + '\n')

        f.close()


def fileExist():
    # print(drawFile)
    if os.path.exists(father_path + os.sep + 'draw.py'):
        # pass
        return True
    else:
        return False
        # shutil.copy(drawFile,father_path+os.sep)
        # f = open(pa,'a')
        # lis = [
        #     'from .draw import label_colormap',
        #     'from .draw import _validate_colormap',
        #     'from .draw import label2rgb',
        #     'from .draw import draw_label',
        #     'from .draw import draw_instances'
        # ]

        # for i in lis:
        #     f.write(i+'\n')

        # f.close()
